@@ -23,46 +23,41 @@ from aliyunsdkdypnsapi.endpoint import endpoint_data
 class GetAuthorizationUrlRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'Dypnsapi', '2017-05-25', 'GetAuthorizationUrl')
+		RpcRequest.__init__(self, 'Dypnsapi', '2017-05-25', 'GetAuthorizationUrl','dypnsapi')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ResourceOwnerId(self):
+	def get_ResourceOwnerId(self): # Long
 		return self.get_query_params().get('ResourceOwnerId')
 
-	def set_ResourceOwnerId(self,ResourceOwnerId):
-		self.add_query_param('ResourceOwnerId',ResourceOwnerId)
-
-	def get_ResourceOwnerAccount(self):
+	def set_ResourceOwnerId(self, ResourceOwnerId):  # Long
+		self.add_query_param('ResourceOwnerId', ResourceOwnerId)
+	def get_ResourceOwnerAccount(self): # String
 		return self.get_query_params().get('ResourceOwnerAccount')
 
-	def set_ResourceOwnerAccount(self,ResourceOwnerAccount):
-		self.add_query_param('ResourceOwnerAccount',ResourceOwnerAccount)
-
-	def get_SchemeId(self):
+	def set_ResourceOwnerAccount(self, ResourceOwnerAccount):  # String
+		self.add_query_param('ResourceOwnerAccount', ResourceOwnerAccount)
+	def get_SchemeId(self): # Long
 		return self.get_query_params().get('SchemeId')
 
-	def set_SchemeId(self,SchemeId):
-		self.add_query_param('SchemeId',SchemeId)
-
-	def get_OwnerId(self):
+	def set_SchemeId(self, SchemeId):  # Long
+		self.add_query_param('SchemeId', SchemeId)
+	def get_OwnerId(self): # Long
 		return self.get_query_params().get('OwnerId')
 
-	def set_OwnerId(self,OwnerId):
-		self.add_query_param('OwnerId',OwnerId)
-
-	def get_PhoneNo(self):
+	def set_OwnerId(self, OwnerId):  # Long
+		self.add_query_param('OwnerId', OwnerId)
+	def get_PhoneNo(self): # String
 		return self.get_query_params().get('PhoneNo')
 
-	def set_PhoneNo(self,PhoneNo):
-		self.add_query_param('PhoneNo',PhoneNo)
-
-	def get_EndDate(self):
+	def set_PhoneNo(self, PhoneNo):  # String
+		self.add_query_param('PhoneNo', PhoneNo)
+	def get_EndDate(self): # String
 		return self.get_query_params().get('EndDate')
 
-	def set_EndDate(self,EndDate):
-		self.add_query_param('EndDate',EndDate)
\ No newline at end of file
+	def set_EndDate(self, EndDate):  # String
+		self.add_query_param('EndDate', EndDate)
