@@ -23,41 +23,37 @@ from aliyunsdkdypnsapi.endpoint import endpoint_data
 class GetMobileRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'Dypnsapi', '2017-05-25', 'GetMobile')
+		RpcRequest.__init__(self, 'Dypnsapi', '2017-05-25', 'GetMobile','dypnsapi')
 		self.set_protocol_type('https')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ResourceOwnerId(self):
+	def get_ResourceOwnerId(self): # Long
 		return self.get_query_params().get('ResourceOwnerId')
 
-	def set_ResourceOwnerId(self,ResourceOwnerId):
-		self.add_query_param('ResourceOwnerId',ResourceOwnerId)
-
-	def get_ResourceOwnerAccount(self):
+	def set_ResourceOwnerId(self, ResourceOwnerId):  # Long
+		self.add_query_param('ResourceOwnerId', ResourceOwnerId)
+	def get_ResourceOwnerAccount(self): # String
 		return self.get_query_params().get('ResourceOwnerAccount')
 
-	def set_ResourceOwnerAccount(self,ResourceOwnerAccount):
-		self.add_query_param('ResourceOwnerAccount',ResourceOwnerAccount)
-
-	def get_AccessToken(self):
+	def set_ResourceOwnerAccount(self, ResourceOwnerAccount):  # String
+		self.add_query_param('ResourceOwnerAccount', ResourceOwnerAccount)
+	def get_AccessToken(self): # String
 		return self.get_query_params().get('AccessToken')
 
-	def set_AccessToken(self,AccessToken):
-		self.add_query_param('AccessToken',AccessToken)
-
-	def get_OwnerId(self):
+	def set_AccessToken(self, AccessToken):  # String
+		self.add_query_param('AccessToken', AccessToken)
+	def get_OwnerId(self): # Long
 		return self.get_query_params().get('OwnerId')
 
-	def set_OwnerId(self,OwnerId):
-		self.add_query_param('OwnerId',OwnerId)
-
-	def get_OutId(self):
+	def set_OwnerId(self, OwnerId):  # Long
+		self.add_query_param('OwnerId', OwnerId)
+	def get_OutId(self): # String
 		return self.get_query_params().get('OutId')
 
-	def set_OutId(self,OutId):
-		self.add_query_param('OutId',OutId)
\ No newline at end of file
+	def set_OutId(self, OutId):  # String
+		self.add_query_param('OutId', OutId)
